@@ -9,12 +9,7 @@ config = Config.getConfig(parentKey='core', key='Logger')
 
 
 import logging
-
-path_log = 'hackingtools.log'
-if not Utils.amIdjango(__file__):
-    path_log = __os.path.join(__os.path.split(__os.path.split(__os.path.split(__os.path.split(__file__)[0])[0])[0])[0], path_log)
-
-logging.basicConfig(filename=path_log, filemode='a', format='%(asctime)s %(levelname)s - %(message)s', datefmt='%Y-%m-%d %H:%M:%S',level=logging.DEBUG)
+logging.basicConfig(filename='hackingtools.log', filemode='a', format='%(asctime)s %(levelname)s-%(message)s', datefmt='%Y-%m-%d %H:%M:%S')
 
 __colorama.init()
 
